==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Projection/IsometricProjection/IsoProject/ts/IsoProject_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>IsoProject</name>
    <message>
        <source>Reference point</source>
        <translation type="obsolete">Referenzpunkt</translation>
    </message>
    <message>
        <location filename="../IsoProjectInit.js" line="+2"/>
        <source>&amp;Isometric Projection</source>
        <translation>&amp;Isometrische Projektion</translation>
    </message>
    <message>
        <source>Back</source>
        <translation type="obsolete">Hinten</translation>
    </message>
    <message>
        <location filename="../IsoProject.ui" line="+17"/>
        <source>Top</source>
        <translation>Oben</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Bottom</source>
        <translation>Unten</translation>
    </message>
    <message>
        <location line="+41"/>
        <source>Left back</source>
        <translation>Links hinten</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Right</source>
        <translation>Rechts</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Right back</source>
        <translation>Rechts hinten</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Rotate selection counter-clockwise before projection</source>
        <translation>Im Gegenuhrzeigersinn rotieren vor Projektion</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Rotate selection clockwise before projection</source>
        <translation>Im Uhrzeigersinn rotieren vor Projektion</translation>
    </message>
    <message>
        <source>Rotate counter-clockwise</source>
        <translation type="obsolete">Im Gegenuhrzeigersinn rotieren</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="obsolete">Im Uhrzeigersinn rotieren</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Scale projection to original size (&apos;isometric drawing&apos;)</source>
        <translation>Projektion in Originalgrösse (&quot;Isometrische Zeichnung&quot;)</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>True scale</source>
        <translation>Wahre Skalierung</translation>
    </message>
    <message>
        <location line="-114"/>
        <source>Left</source>
        <translation>Links</translation>
    </message>
    <message>
        <source>Front</source>
        <translation type="obsolete">Vorderseite</translation>
    </message>
    <message>
        <source>Isometric Projection</source>
        <translation type="obsolete">Isometrische Projektion</translation>
    </message>
    <message>
        <source>Target point</source>
        <translation type="obsolete">Zielpunkt</translation>
    </message>
    <message>
        <source>ProjectionType</source>
        <translation type="obsolete">ProjectionType</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Projection/IsometricProjection/IsoProject/ts/IsoProject_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>IsoProject</name>
    <message>
        <source>Reference point</source>
        <translation type="obsolete">Referenzpunkt</translation>
    </message>
    <message>
        <location filename="../IsoProjectInit.js" line="+2"/>
        <source>&amp;Isometric Projection</source>
        <translation>&amp;Isometrische Projektion</translation>
    </message>
    <message>
        <source>Back</source>
        <translation type="obsolete">Hinten</translation>
    </message>
    <message>
        <location filename="../IsoProject.ui" line="+17"/>
        <source>Top</source>
        <translation>Oben</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Bottom</source>
        <translation>Unten</translation>
    </message>
    <message>
        <location line="+41"/>
        <source>Left back</source>
        <translation>Links hinten</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Right</source>
        <translation>Rechts</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Right back</source>
        <translation>Rechts hinten</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Rotate selection counter-clockwise before projection</source>
        <translation>Im Gegenuhrzeigersinn rotieren vor Projektion</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Rotate selection clockwise before projection</source>
        <translation>Im Uhrzeigersinn rotieren vor Projektion</translation>
    </message>
    <message>
        <source>Rotate counter-clockwise</source>
        <translation type="obsolete">Im Gegenuhrzeigersinn rotieren</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="obsolete">Im Uhrzeigersinn rotieren</translation>
    </message>
    <message>
        <source>Scale projection to original size (&apos;isometric drawing&apos;)</source>
        <translation type="vanished">Projektion in Originalgrösse (&quot;Isometrische Zeichnung&quot;)</translation>
    </message>
    <message>
        <source>True scale</source>
        <translation type="vanished">Wahre Skalierung</translation>
    </message>
    <message>
        <location line="-93"/>
        <source>Left</source>
        <translation>Links</translation>
    </message>
    <message>
        <source>Front</source>
        <translation type="obsolete">Vorderseite</translation>
    </message>
    <message>
        <source>Isometric Projection</source>
        <translation type="obsolete">Isometrische Projektion</translation>
    </message>
    <message>
        <source>Target point</source>
        <translation type="obsolete">Zielpunkt</translation>
    </message>
    <message>
        <source>ProjectionType</source>
        <translation type="obsolete">ProjectionType</translation>
    </message>
    <message>
        <location filename="../IsoProject.js" line="+50"/>
        <source>Isometric</source>
        <translation>Isometrisch</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Isometric True Scale</source>
        <translation>Isometrisch wahre Skalierung</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Planometric</source>
        <translation>Planometrisch</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dimetric</source>
        <translation>Dimetrisch</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>Cabinet</source>
        <translation>Kabinett</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Cavalier</source>
        <translation>Kavalier</translation>
    </message>
</context>
</TS>
